# bollhav ⚽ 🌊

Model definition framework that standardizes code at the model and the pipeline level.

Several database implementations available soon.

- [Model level](MODEL.md)
- [Pipeline level](Environment)
- [Postgres](POSTGRES.md)
- [Parquet](PARQUET.md)


## Installation
```bash
pip install bollhav
```

## Testing

Tests use `pytest`. Run the full suite:
```bash
pytest tests/
```
